@@ -132,6 +132,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_cloudwatch
@@ -153,15 +155,15 @@ class KinesisStreamsToKinesisFirehoseToS3(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_firehose_props: typing.Any = None,
-        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
-        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
+        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -182,6 +184,10 @@ class KinesisStreamsToKinesisFirehoseToS3(
         :since: 1.68.0
         :summary: Constructs a new instance of the KinesisStreamsToKinesisFirehoseToS3 class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(KinesisStreamsToKinesisFirehoseToS3.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = KinesisStreamsToKinesisFirehoseToS3Props(
             bucket_props=bucket_props,
             create_cloud_watch_alarms=create_cloud_watch_alarms,
@@ -265,15 +271,15 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
     def __init__(
         self,
         *,
-        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_firehose_props: typing.Any = None,
-        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
-        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
+        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''The properties for the KinesisStreamsToKinesisFirehoseToS3 class.
@@ -297,6 +303,18 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
             logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(KinesisStreamsToKinesisFirehoseToS3Props.__init__)
+            check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
+            check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
+            check_type(argname="argument existing_bucket_obj", value=existing_bucket_obj, expected_type=type_hints["existing_bucket_obj"])
+            check_type(argname="argument existing_logging_bucket_obj", value=existing_logging_bucket_obj, expected_type=type_hints["existing_logging_bucket_obj"])
+            check_type(argname="argument existing_stream_obj", value=existing_stream_obj, expected_type=type_hints["existing_stream_obj"])
+            check_type(argname="argument kinesis_firehose_props", value=kinesis_firehose_props, expected_type=type_hints["kinesis_firehose_props"])
+            check_type(argname="argument kinesis_stream_props", value=kinesis_stream_props, expected_type=type_hints["kinesis_stream_props"])
+            check_type(argname="argument logging_bucket_props", value=logging_bucket_props, expected_type=type_hints["logging_bucket_props"])
+            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
+            check_type(argname="argument log_s3_access_logs", value=log_s3_access_logs, expected_type=type_hints["log_s3_access_logs"])
         self._values: typing.Dict[str, typing.Any] = {}
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
